@@ -350,7 +350,7 @@ Provision::Unix - provision hosting accounts on unix systems
 
 =head1 VERSION
 
-version 1.07
+version 1.08
 
 =head1 SYNOPSIS
 
@@ -517,35 +517,13 @@ You can find documentation for this module with the perldoc command.
 
     perldoc Provision::Unix
 
-You can also look for information at:
-
-=over 4
-
-=item * RT: CPAN's request tracker
-
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Provision-Unix>
-
-=item * AnnoCPAN: Annotated CPAN documentation
-
-L<http://annocpan.org/dist/Provision-Unix>
-
-=item * CPAN Ratings
-
-L<http://cpanratings.perl.org/d/Provision-Unix>
-
-=item * Search CPAN
-
-L<http://search.cpan.org/dist/Provision-Unix>
-
-=back
-
 =head1 AUTHOR
 
 Matt Simerson <msimerson@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by The Network People, Inc..
+This software is copyright (c) 2015 by The Network People, Inc..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
